@@ -1,3 +1,3 @@
 from union.artifacts import Artifact, DataCard, ModelCard, OnArtifact
 
-__all__ = ["Artifact", "OnArtifact", "DataCard", "ModelCard"]
+__all__ = ["Artifact", "DataCard", "ModelCard", "OnArtifact"]
